Change in ...osmo-bts[master]: osmo-bts-trx/scheduler: also detect TSC for Access Bursts on PDCH

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

fixeria gerrit-no-reply at lists.osmocom.org
Wed Oct 2 16:30:06 UTC 2019


fixeria has uploaded this change for review. ( https://gerrit.osmocom.org/c/osmo-bts/+/15657


Change subject: osmo-bts-trx/scheduler: also detect TSC for Access Bursts on PDCH
......................................................................

osmo-bts-trx/scheduler: also detect TSC for Access Bursts on PDCH

If a logical channel, on which an Access Burst has been received,
is not either of RACH, PDTCH or PTCCH, then this is a handover
Access Burst, which is always encoded as 8-bit and shall contain
the generic training sequence (TS0).

Access Bursts on a PDCH time-slot are not related to handover.

Change-Id: If7d6135d6c4d7f9bd71d9fab6f8adc3f8cfd10ea
---
M src/osmo-bts-trx/scheduler_trx.c
1 file changed, 4 insertions(+), 3 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-bts refs/changes/57/15657/1

diff --git a/src/osmo-bts-trx/scheduler_trx.c b/src/osmo-bts-trx/scheduler_trx.c
index 8b0c761..421cf16 100644
--- a/src/osmo-bts-trx/scheduler_trx.c
+++ b/src/osmo-bts-trx/scheduler_trx.c
@@ -796,9 +796,10 @@
 	enum rach_synch_seq_t synch_seq = RACH_SYNCH_SEQ_TS0;
 	int best_score = 127 * RACH_SYNCH_SEQ_LEN;
 
-	/* If chan != TRXC_RACH, this is a handover RACH, which is always encoded
-	 * as 8-bit and should contain the generic training sequence (TS0). */
-	if (chan == TRXC_RACH) {
+	/* If logical channel is not either of RACH, PDTCH or PTCCH, this is a
+	 * handover Access Burst, which is always encoded as 8-bit and shall
+	 * contain the generic training sequence (TS0). */
+	if (chan == TRXC_RACH || chan == TRXC_PDTCH || chan == TRXC_PTCCH) {
 		if (bi->flags & TRX_BI_F_TS_INFO)
 			synch_seq = (enum rach_synch_seq_t) bi->tsc;
 		else

-- 
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/15657
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: If7d6135d6c4d7f9bd71d9fab6f8adc3f8cfd10ea
Gerrit-Change-Number: 15657
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria <axilirator at gmail.com>
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20191002/48184f2d/attachment.htm>


More information about the gerrit-log mailing list